diff mbox series

[v2] KVM: x86: add missing MODULE_DESCRIPTION() macros

Message ID 20240622-md-kvm-v2-1-29a60f7c48b1@quicinc.com (mailing list archive)
State New, archived
Headers show
Series [v2] KVM: x86: add missing MODULE_DESCRIPTION() macros | expand

Commit Message

Jeff Johnson June 23, 2024, 5:44 a.m. UTC
Fix the following allmodconfig 'make W=1' warnings when building for x86:
WARNING: modpost: missing MODULE_DESCRIPTION() in arch/x86/kvm/kvm.o
WARNING: modpost: missing MODULE_DESCRIPTION() in arch/x86/kvm/kvm-intel.o
WARNING: modpost: missing MODULE_DESCRIPTION() in arch/x86/kvm/kvm-amd.o

Signed-off-by: Jeff Johnson <quic_jjohnson@quicinc.com>
---
Changes in v2:
- Per Sean:
  - updated SVM and VMX descriptions to add "support for"
  - updated kvm_main description to use the term Hypervisor (in 2 places)
- Link to v1: https://lore.kernel.org/r/20240528-md-kvm-v1-1-c1b86f0f5112@quicinc.com
---
 arch/x86/kvm/svm/svm.c | 1 +
 arch/x86/kvm/vmx/vmx.c | 1 +
 virt/kvm/kvm_main.c    | 3 ++-
 3 files changed, 4 insertions(+), 1 deletion(-)


---
base-commit: 2bfcfd584ff5ccc8bb7acde19b42570414bf880b
change-id: 20240528-md-kvm-36f20bc4a5b0

Comments

Sean Christopherson June 28, 2024, 10:55 p.m. UTC | #1
On Sat, 22 Jun 2024 22:44:55 -0700, Jeff Johnson wrote:
> Fix the following allmodconfig 'make W=1' warnings when building for x86:
> WARNING: modpost: missing MODULE_DESCRIPTION() in arch/x86/kvm/kvm.o
> WARNING: modpost: missing MODULE_DESCRIPTION() in arch/x86/kvm/kvm-intel.o
> WARNING: modpost: missing MODULE_DESCRIPTION() in arch/x86/kvm/kvm-amd.o

I split this into two commits.  The x86 changes went to `kvm-x86 misc`, and the
generic KVM one went to `kvm-x86 generic`.  I split them partly so that I could
opportunistically delete the VT-x comment from kvm_main.c, which was comically
stale.

Holler if anything looks wrong.  Thanks!

[1/1] KVM: x86: add missing MODULE_DESCRIPTION() macros
      https://github.com/kvm-x86/linux/commit/8815d77cbc99

[1/1] KVM: Add missing MODULE_DESCRIPTION()
      https://github.com/kvm-x86/linux/commit/25bc6af60f61

--
https://github.com/kvm-x86/linux/tree/next
Jeff Johnson June 28, 2024, 11:10 p.m. UTC | #2
On 6/28/2024 3:55 PM, Sean Christopherson wrote:
> On Sat, 22 Jun 2024 22:44:55 -0700, Jeff Johnson wrote:
>> Fix the following allmodconfig 'make W=1' warnings when building for x86:
>> WARNING: modpost: missing MODULE_DESCRIPTION() in arch/x86/kvm/kvm.o
>> WARNING: modpost: missing MODULE_DESCRIPTION() in arch/x86/kvm/kvm-intel.o
>> WARNING: modpost: missing MODULE_DESCRIPTION() in arch/x86/kvm/kvm-amd.o
> 
> I split this into two commits.  The x86 changes went to `kvm-x86 misc`, and the
> generic KVM one went to `kvm-x86 generic`.  I split them partly so that I could
> opportunistically delete the VT-x comment from kvm_main.c, which was comically
> stale.
> 
> Holler if anything looks wrong.  Thanks!
> 
> [1/1] KVM: x86: add missing MODULE_DESCRIPTION() macros
>       https://github.com/kvm-x86/linux/commit/8815d77cbc99
> 
> [1/1] KVM: Add missing MODULE_DESCRIPTION()
>       https://github.com/kvm-x86/linux/commit/25bc6af60f61
> 
> --
> https://github.com/kvm-x86/linux/tree/next
LGTM, thanks!
diff mbox series

Patch

diff --git a/arch/x86/kvm/svm/svm.c b/arch/x86/kvm/svm/svm.c
index c8dc25886c16..e484a95ffbad 100644
--- a/arch/x86/kvm/svm/svm.c
+++ b/arch/x86/kvm/svm/svm.c
@@ -53,6 +53,7 @@ 
 #include "svm_onhyperv.h"
 
 MODULE_AUTHOR("Qumranet");
+MODULE_DESCRIPTION("KVM support for SVM (AMD-V) extensions");
 MODULE_LICENSE("GPL");
 
 #ifdef MODULE
diff --git a/arch/x86/kvm/vmx/vmx.c b/arch/x86/kvm/vmx/vmx.c
index 6051fad5945f..2ec2b7105056 100644
--- a/arch/x86/kvm/vmx/vmx.c
+++ b/arch/x86/kvm/vmx/vmx.c
@@ -74,6 +74,7 @@ 
 #include "posted_intr.h"
 
 MODULE_AUTHOR("Qumranet");
+MODULE_DESCRIPTION("KVM support for VMX (Intel VT-x) extensions");
 MODULE_LICENSE("GPL");
 
 #ifdef MODULE
diff --git a/virt/kvm/kvm_main.c b/virt/kvm/kvm_main.c
index 14841acb8b95..ffe4ba998225 100644
--- a/virt/kvm/kvm_main.c
+++ b/virt/kvm/kvm_main.c
@@ -1,6 +1,6 @@ 
 // SPDX-License-Identifier: GPL-2.0-only
 /*
  * Kernel-based Virtual Machine driver for Linux
  *
  * This module enables machines with Intel VT-x extensions to run virtual
  * machines without emulation or binary translation.
@@ -74,6 +74,7 @@ 
 #define ITOA_MAX_LEN 12
 
 MODULE_AUTHOR("Qumranet");
+MODULE_DESCRIPTION("Kernel-based Virtual Machine (KVM) Hypervisor");
 MODULE_LICENSE("GPL");
 
 /* Architectures should define their poll value according to the halt latency */
@@ -1,6 +1,6 @@ 
 // SPDX-License-Identifier: GPL-2.0-only
 /*
- * Kernel-based Virtual Machine driver for Linux
+ * Kernel-based Virtual Machine (KVM) Hypervisor
  *
  * This module enables machines with Intel VT-x extensions to run virtual